@@ -1,4 +1,4 @@
-package Netstack::Connector::Role;
+package Netstack::Config::Connector::Role;
 
 #------------------------------------------------------------------------------
 # 加载扩展模块
@@ -11,7 +11,7 @@ use Moose::Role;
 use namespace::autoclean;
 
 #------------------------------------------------------------------------------
-# 继承 Netstack::Connector::Role 必须实现的方法
+# 继承 Netstack::Config::Connector::Role 必须实现的方法
 #------------------------------------------------------------------------------
 requires '_buildPrompt';
 requires '_buildCommands';
@@ -20,11 +20,11 @@ requires '_buildBufferCode';
 requires 'runCommands';
 
 #------------------------------------------------------------------------------
-# 定义设备联结 Netstack::Connector::Role 方法属性
+# 定义设备联结 Netstack::Config::Connector::Role 方法属性
 #------------------------------------------------------------------------------
 has exp => (
   is      => 'ro',
-  default => sub { Expect->new },
+  default => sub {Expect->new},
   # Expect 方法权限下放，该属性将代理响应
   handles => [ 'spawn', 'expect', 'interact' ]
 );
@@ -48,7 +48,6 @@ has password => (
 
 has port => (
   is        => 'ro',
-  default   => '22',
   predicate => 'hasPort'
 );
 
@@ -60,6 +59,8 @@ has enPassword => (
 
 has proto => (
   is       => 'ro',
+  traits   => [ "Enumeration" ],
+  enum     => [ qw/ssh telnet/ ],
   required => 1,
   default  => 'ssh',
 );
@@ -96,7 +97,7 @@ has commands => (
   is      => 'rw',
   isa     => 'ArrayRef[Str]',
   writer  => 'setCommands',
-  traits  => ['Array'],
+  traits  => [ 'Array' ],
   handles => {
     addCommand  => 'unshift',
     pushCommand => 'push'
@@ -142,7 +143,7 @@ sub login {
   my $self = shift;
 
   # 检查是否已经登录过 | 边界条件检查
-  return {success => 1} if $self->status == 1;
+  return { success => 1 } if $self->status == 1;
 
   # 尝试连接设备,支持异常重连机制
   try {
@@ -151,7 +152,7 @@ sub login {
   }
   catch {
     if (/RSA modulus too small/mi) {
-      try { $self->connect('-v -1 -c des ') }
+      try {$self->connect('-v -1 -c des ')}
       catch {
         return {
           success => 0,
@@ -191,18 +192,46 @@ sub login {
   };
 }
 
+#------------------------------------------------------------------------------
+# _spawn_command 根据协议生成登录脚本
+#------------------------------------------------------------------------------
+sub _spawn_command {
+  my ($self, $args) = @_;
+  $args //= '';
+  # 初始化变量
+  my $command;
+
+  # 绑定已有变量
+  my $user = $self->username;
+  my $host = $self->host;
+  my $port = $self->port;
+  my $proto = $self->proto;
+
+  # 判断是否定义非标端口
+  if ($self->hasPort) {
+    # 根据不同协议生成脚本，telnet 协议兼容性可能有问题
+    if ($proto =~ /telnet/i) {
+      $command = $proto . " $args" . " -l $user $host $port";
+    }
+    elsif ($proto =~ /ssh/i) {
+      $command = $proto . " $args" . " -l $user $host -p $port";
+    }
+  }
+  else {
+    $command = $proto . " $args" . " -l $user $host";
+  }
+
+  # 返回计算结果
+  return $command;
+}
+
 #------------------------------------------------------------------------------
 # connect 设备联机登录
 #------------------------------------------------------------------------------
 sub connect {
-  my ( $self, $args ) = @_;
-  # 检查是否携带变量并初始化
-  $args = defined $args ? $args : '';
-  # # 检查是否携带端口信息
-  $args . " -p $self->{port}" if $self->hasPort;
+  my ($self, $args) = @_;
 
   # 初始化变量
-  my $host     = $self->host;
   my $username = $self->username;
   my $password = $self->password;
 
@@ -216,8 +245,8 @@ sub connect {
   $exp->log_stdout(0);
 
   # 设置登录逻辑
-  my $status  = 1;
-  my $command = $self->proto . " $args" . " -l $username $host";
+  my $status = 1;
+  my $command = $self->_spawn_command($args);
   # 尝试登录设备并执行异常拦截
   $self->spawn($command) || confess __PACKAGE__ . " case0) Cannot spawn $command: $!\n";
 
@@ -226,39 +255,39 @@ sub connect {
     15,
     # 自动输入 yes
     [ qr/continue connecting \(yes\/no/mi => sub {
-        $exp->send("yes\n");
-        exp_continue;
-      }
+      $exp->send("yes\n");
+      exp_continue;
+    }
     ],
     # 自动输入密码,且仅输入一次
     [ qr/password:/mi => sub {
-        if ( $status == 1 ) {
-          $status = 0;
-          $exp->send("$password\n");
-        }
-        else {
-          confess __PACKAGE__ . " case1) 登录($self->{host})失败,请提供正确的账号密码;";
-        }
-        exp_continue;
+      if ($status == 1) {
+        $status = 0;
+        $exp->send("$password\n");
       }
+      else {
+        confess __PACKAGE__ . " case1) 登录($self->{host})失败,请提供正确的账号密码;";
+      }
+      exp_continue;
+    }
     ],
     # 自动输入账号 | 脚本已经绑定用户名
     [ qr/(ogin|name):\s*$/mi => sub {
-        $exp->send("$username\n");
-        exp_continue;
-      }
+      $exp->send("$username\n");
+      exp_continue;
+    }
     ],
     # 捕捉到脚本下发正常提示符
     [ $self->prompt => sub {
-        $self->setStatus(1);
-        # 缺省情况下 没有 enable 模式
-        $self->setEnabled(1) unless $self->definedEnablePrompt;
-      }
+      $self->setStatus(1);
+      # 缺省情况下 没有 enable 模式
+      $self->setEnabled(1) unless $self->definedEnablePrompt;
+    }
     ],
   );
 
   # Expect是否异常
-  if ( defined $ret[1] ) {
+  if (defined $ret[1]) {
     confess __PACKAGE__ . " case2) 登录节点($self->{host})期间捕捉到异常: $ret[3] . $ret[1]";
   }
 }
@@ -267,7 +296,7 @@ sub connect {
 # send 设备发送指令入口函数，接收字符串
 #------------------------------------------------------------------------------
 sub send {
-  my ( $self, $command ) = @_;
+  my ($self, $command) = @_;
   # 执行脚本
   $self->exp->send($command);
 }
@@ -284,9 +313,9 @@ sub waitfor {
 
   # 初始化缓存代码
   my $codeARef = [];
-  my $mapping  = $self->bufferCode;
+  my $mapping = $self->bufferCode;
   # 遍历字典
-  while ( my ( $wait, $action ) = each $mapping->%* ) {
+  while (my ($wait, $action) = each $mapping->%*) {
     push $codeARef->@*, [
       $wait => sub {
         $buff .= $exp->before . $exp->match;
@@ -303,9 +332,9 @@ sub waitfor {
   ];
 
   # 动态加载交互式代码
-  my @ret = $exp->expect( 15, $codeARef->@* );
+  my @ret = $self->expect(15, $codeARef->@*);
   # 异常捕捉
-  if ( defined $ret[1] ) {
+  if (defined $ret[1]) {
     confess __PACKAGE__ . " 节点($self->{host})脚本执行期间捕捉到异常：$ret[3] . $ret[1]";
   }
 
@@ -327,10 +356,10 @@ sub getConfig {
 
   # 抓取设备命令脚本，输入不分页命令加速输出
   my $commands = $self->getCommands;
-  my $ret      = $self->execCommands( $commands->@* );
+  my $ret = $self->execCommands($commands->@*);
 
   # 判断是否执行成功
-  if ( $ret->{success} == 1 ) {
+  if ($ret->{success} == 1) {
     return {
       success => 1,
       config  => $ret->{result}
@@ -348,27 +377,27 @@ sub getConfig {
 # execCommands 执行批量下发脚本
 #------------------------------------------------------------------------------
 sub execCommands {
-  my ( $self, @commands ) = @_;
+  my ($self, @commands) = @_;
 
   # 判断是否已登陆设备
-  if ( $self->status == 0 ) {
+  if ($self->status == 0) {
     $self->login;
     # 未成功登录设备，异常拦截
-    if ( $self->status == 0 ) {
+    if ($self->status == 0) {
       return {
         success     => 0,
-        failCommand => join( "\n", @commands ),
+        failCommand => join("\n", @commands),
         reason      => "设备登录异常,无法下发配置"
       };
     }
     # 检查是否进入 enable 状态
-    if ( $self->enabled == 0 ) {
+    if ($self->enabled == 0) {
       # 尝试进入 enable
       $self->enable;
       # 异常拦截
       return {
         success     => 0,
-        failCommand => join( "\n", @commands ),
+        failCommand => join("\n", @commands),
         reason      => "设备无法进入enable模式,无法下发配置"
       } if $self->enabled == 0;
     }
@@ -377,9 +406,9 @@ sub execCommands {
   # 初始化 result 变量，并开始执行命令
   my $result = "";
   # 初始化 commands 属性
-  $self->setCommands( \@commands );
+  $self->setCommands(\@commands);
   # 遍历接受到的命令行
-  while ( my $cmd = pop $self->commands->@* ) {
+  while (my $cmd = pop $self->commands->@*) {
     # 自动跳过空白行
     next if $cmd =~ /^\s*$/;
     # 执行具体的脚本
@@ -388,8 +417,8 @@ sub execCommands {
     my $buff = $self->waitfor;
 
     # 异常拦截，基于正则表达式判断是否匹配错误码
-    foreach my $error ( $self->errorCode->@* ) {
-      if ( $buff =~ /$error/ ) {
+    foreach my $error ($self->errorCode->@*) {
+      if ($buff =~ /$error/) {
         return {
           success     => 0,
           failCommand => $cmd,
@@ -421,37 +450,37 @@ sub enable {
   # 初始化变量
   my $username = $self->username;
   my $enPasswd = $self->enPassword // $self->password;
-  my $exp      = $self->exp;
+  my $exp = $self->exp;
 
   # 判断需要进入 enable 后执行
-  $exp->send( $self->getEnableCommand . "\n" );
+  $exp->send($self->getEnableCommand . "\n");
   my $status = 1;
-  my @ret    = $self->expect(
+  my @ret = $self->expect(
     15,
     [ qr/assword:\s*$/mi => sub {
-        if ( $status == 1 ) {
-          $status = 0;
-          $exp->send("$enPasswd\n");
-        }
-        else {
-          confess __PACKAGE__ . " case5) 请正确填写用户和enable password";
-        }
-        exp_continue;
+      if ($status == 1) {
+        $status = 0;
+        $exp->send("$enPasswd\n");
       }
+      else {
+        confess __PACKAGE__ . " case5) 请正确填写用户和enable password";
+      }
+      exp_continue;
+    }
     ],
     [ qr/(ogin|name):\s*$/mi => sub {
-        $exp->send("$username\n");
-        exp_continue;
-      }
+      $exp->send("$username\n");
+      exp_continue;
+    }
     ],
     [ $self->enPrompt => sub {
-        $self->setEnabled(1);
-      }
+      $self->setEnabled(1);
+    }
     ]
   );
 
   # 异常回显信号捕捉
-  if ( defined $ret[1] ) {
+  if (defined $ret[1]) {
     confess __PACKAGE__ . " case6) 交互式提供enable密码期间报错：$ret[3] . $ret[1]";
   }
 }
@@ -466,10 +495,10 @@ sub deploy {
     success     => 0,
     failCommand => "not defined commands",
     reason      => "check defined command or not",
-    }
+  }
     if scalar $self->commands->@* == 0;
 
   # 遍历已有的 commands
-  return $self->execCommands( $self->commands->@* );
+  return $self->execCommands($self->commands->@*);
 }
 1;
